------------------------------------------------------
-- Beispielskript zur SNEK 6 im April 2018 in Nrnberg
-- Autor: Bernd Jungbluth
-- Keine Gewhrleistung, keine Haftung

-- Installation Beispieldatenbank SNEK 6
------------------------------------------------------

USE master;
GO

CREATE DATABASE SNEK; 
GO
ALTER DATABASE SNEK SET TRUSTWORTHY ON;
GO

USE SNEK
GO

-- Schemata
CREATE SCHEMA Einkauf;
GO
CREATE SCHEMA Personal;
GO
CREATE SCHEMA Verkauf;
GO

CREATE TABLE dbo.Kontakte
(	KontaktID		int				NOT NULL	IDENTITY(1,1),
	Kontaktart		char(1)			NOT NULL,
	Firma			nvarchar(255)	NOT NULL,
	Namenszusatz	nvarchar(255)	NULL,
	Strasse			nvarchar(60)	NOT NULL,
	Ort				nvarchar(100)	NOT NULL,
	RegionID		int				NULL,
	PLZ				nvarchar(10)	NOT NULL,
	Staat			nvarchar(15)	NULL,
	Telefon			nvarchar(25)	NULL,
	Email			nvarchar(255)	NULL,
	iTS				timestamp		NOT NULL,
	CONSTRAINT PK__dbo_Kontakte_KontaktID PRIMARY KEY CLUSTERED (KontaktID ASC));
ALTER TABLE dbo.Kontakte ADD CONSTRAINT UK__dbo_Kontakte_Kontaktart_Firma UNIQUE NONCLUSTERED (KontaktID ASC);
GO

CREATE TABLE dbo.Ansprechpartner
(	AnsprechpartnerID	int				NOT NULL	IDENTITY(1,1) ,
	KontaktID			int				NOT NULL,
	Nachname			nvarchar(100)	NOT NULL,
	Vorname				nvarchar(20)	NULL,
	Anrede				nvarchar(5)		NULL,
	Position			nvarchar(100)	NULL,
	Telefon				nvarchar(25)	NULL,
	Mobil				nvarchar(15)	NULL,
	Email				nvarchar(255)	NULL,
	iTS					timestamp		NOT NULL,
	CONSTRAINT PK__dbo_Ansprechpartner_AnsprechpartnerID PRIMARY KEY CLUSTERED (AnsprechpartnerID ASC));
ALTER TABLE dbo.Ansprechpartner ADD CONSTRAINT UK__dbo_Ansprechpartner_KontaktID_Email UNIQUE NONCLUSTERED (AnsprechpartnerID ASC);
ALTER TABLE dbo.Ansprechpartner WITH CHECK ADD CONSTRAINT FK__dbo_Ansprechpartner__dbo_Kontakte_KontaktID FOREIGN KEY(KontaktID) REFERENCES dbo.Kontakte (KontaktID);
ALTER TABLE dbo.Ansprechpartner CHECK CONSTRAINT FK__dbo_Ansprechpartner__dbo_Kontakte_KontaktID;
GO

-- Tabellen
CREATE TABLE dbo.Regionen
(	RegionID	int				NOT NULL	IDENTITY(1,1),
	Region		nvarchar(50)	NOT NULL,
	CONSTRAINT PK__dbo_Regionen_RegionenID PRIMARY KEY CLUSTERED (RegionID ASC),
	CONSTRAINT UK__dbo_Regionen_Region UNIQUE NONCLUSTERED (Region ASC));
ALTER TABLE dbo.Kontakte WITH CHECK ADD CONSTRAINT FK__dbo_Kontakte__dbo_Regionen_RegionID FOREIGN KEY(RegionID) REFERENCES dbo.Regionen (RegionID);
ALTER TABLE dbo.Kontakte CHECK CONSTRAINT FK__dbo_Kontakte__dbo_Regionen_RegionID;
GO

CREATE TABLE Einkauf.Produkte
(	ProduktID				int				NOT NULL	IDENTITY(1,1) ,
	Produkt					nvarchar(50)	NOT NULL,
	ProduktBeschreibung		nvarchar(max)	NULL,
	Herstellungskosten		money			NULL,
	ProduktgruppeID			int				NULL,
	ImVerkauf				bit				NULL,
	KontaktID				int				NULL,
	iTS						timestamp		NOT NULL,
	CONSTRAINT PK__Einkauf_Produkte_ProdukteD PRIMARY KEY CLUSTERED (ProduktID ASC));
GO

CREATE TABLE Einkauf.Produktgruppen
(	ProduktgruppeID				int				NOT NULL	IDENTITY(1,1) ,
	ProduktgruppeBezeichnung	nvarchar(50)	NOT NULL,
	ProduktgruppeBeschreibung	nvarchar(max)	NULL,
	iTS							timestamp		NOT NULL,
	CONSTRAINT PK__Einkauf_Produktgruppen_ProduktgruppeID PRIMARY KEY CLUSTERED (ProduktgruppeID ASC));
GO

CREATE TABLE Personal.Bewerber
(	BewerberID		int				NOT NULL	IDENTITY(1,1) ,
	StellenID		nvarchar(30)	NULL,
	Nachname		nvarchar(20)	NOT NULL,
	Vorname			nvarchar(10)	NOT NULL,
	Strasse			nvarchar(25)	NOT NULL,
	Hausnummer		nvarchar(25)	NOT NULL,
	PLZ				nvarchar(10)	NOT NULL,
	Ort				nvarchar(50)	NOT NULL,
	Geburtsdatum	datetime2(0)	NULL,
	Mobil			nvarchar(4)		NULL,
	Email			nvarchar(255)	NULL,
	Gehaltswunsch	money			NOT NULL,
	Religion		nvarchar(50)	NULL,
	Bemerkungen		nvarchar(4000)	NULL,
	iTS				timestamp		NOT NULL,
	CONSTRAINT PK__Personal_Bewerber_BewerberID PRIMARY KEY CLUSTERED (BewerberID ASC));
GO

CREATE TABLE Personal.Mitarbeiter
(	MitarbeiterID	int				NOT NULL	IDENTITY(1,1),
	PersonalNr		char(12)		NOT NULL,
	Nachname		nvarchar(20)	NOT NULL,
	Vorname			nvarchar(10)	NOT NULL,
	Position		nvarchar(30)	NULL,
	Anrede			nvarchar(25)	NOT NULL,
	Geburtsdatum	datetime2(0)	NULL,
	Einstellung		datetime2(0)	NOT NULL,
	Durchwahl		nvarchar(4)		NULL,
	Mobil			nvarchar(4)		NULL,
	Email			nvarchar(255)	NULL,
	Bemerkungen		nvarchar(4000)	NULL,
	Vorgesetzter	int				NULL,
	AktuellesGehalt	money			NOT NULL,
	Religion		nvarchar(50)	NULL,
	BenutzerID		varbinary(85)	NULL,
	iTS				timestamp		NOT NULL,
	CONSTRAINT PK__Personal_Mitarbeiter_MitarbeiterID PRIMARY KEY CLUSTERED (MitarbeiterID ASC));
ALTER TABLE Personal.Mitarbeiter ADD CONSTRAINT UK__Personal_Mitarbeiter_PersonalNr UNIQUE NONCLUSTERED (PersonalNr ASC);
GO

CREATE TABLE Verkauf.Artikel
(	ArtikelID				int				NOT NULL	IDENTITY(1,1) ,
	Matchcode				nvarchar(9)		NOT NULL,
	Artikel					nvarchar(50)	NOT NULL,
	Artikelbeschreibung		nvarchar(max)	NULL,
	ArtikelgruppeID			int				NOT NULL,
	Verkaufspreis			money			NULL,
	Groesse					nvarchar(5)		NULL,
	Farbe					nvarchar(10)	NULL,
	Inaktiv					bit				NOT NULL,
	iTS						timestamp		NOT NULL,
	CONSTRAINT PK__Verkauf_Artikel_ArtikelID PRIMARY KEY CLUSTERED (ArtikelID ASC));
GO

CREATE TABLE Verkauf.Artikelgruppen
(	ArtikelgruppeID		int				NOT NULL	IDENTITY(1,1) ,
	Artikelgruppe		nvarchar(50)	NOT NULL,
	AgBeschreibung		nvarchar(max)	NULL,
	iTS					timestamp		NOT NULL,
	CONSTRAINT PK__Verkauf_Artikelgruppen_ArtikelgruppeID PRIMARY KEY CLUSTERED (ArtikelgruppeID ASC));
GO

CREATE TABLE Verkauf.Auftraege
(	AuftragID		int				NOT NULL	IDENTITY(1,1) ,
	KontaktID		int				NOT NULL,
	MitarbeiterID	int				NOT NULL,
	Auftragsdatum	datetime2(0)	NOT NULL,
	iTS				timestamp		NOT NULL,
	CONSTRAINT PK__Verkauf_Auftraege_AuftragID PRIMARY KEY CLUSTERED (AuftragID ASC));
GO

CREATE TABLE Verkauf.Auftragspositionen
(	AuftragspositionID	int			NOT NULL	IDENTITY(1,1) ,
	AuftragID			int			NOT NULL,
	ArtikelID			int			NOT NULL,
	Position			int			NOT NULL,
	Einzelpreis			money		NOT NULL,
	Menge				smallint	NOT NULL,
	iTS					timestamp	NOT NULL,
	CONSTRAINT PK__Verkauf_Auftragspositionen__Verkauf_AuftragspositionID PRIMARY KEY CLUSTERED (AuftragspositionID ASC));
GO

CREATE TABLE Verkauf.Gebietszuordnungen
(	GebietszuordnungID	int		NOT	NULL	IDENTITY(1,1),
	MitarbeiterID		int		NOT NULL,
	RegionID			int		NOT NULL,
	CONSTRAINT PK__Verkauf_Gebietszuordnungen_GebietszuordnungID PRIMARY KEY CLUSTERED (GebietszuordnungID ASC),
	CONSTRAINT UK__Verkauf_Gebietszuordnungen_MitarbeiterID_RegionID UNIQUE NONCLUSTERED (MitarbeiterID ASC, RegionID ASC));
ALTER TABLE Verkauf.Gebietszuordnungen WITH CHECK ADD CONSTRAINT FK__Verkauf_Gebietszuordnungen__dbo_Regionen_RegionID FOREIGN KEY(RegionID) REFERENCES dbo.Regionen (RegionID);
ALTER TABLE Verkauf.Gebietszuordnungen CHECK CONSTRAINT FK__Verkauf_Gebietszuordnungen__dbo_Regionen_RegionID;
ALTER TABLE Verkauf.Gebietszuordnungen WITH CHECK ADD CONSTRAINT FK__Verkauf_Gebietszuordnungen__Personal_Mitarbeiter_MitarbeiterID FOREIGN KEY(MitarbeiterID) REFERENCES Personal.Mitarbeiter (MitarbeiterID);
ALTER TABLE Verkauf.Gebietszuordnungen CHECK CONSTRAINT FK__Verkauf_Gebietszuordnungen__Personal_Mitarbeiter_MitarbeiterID;
GO


-- Gespeicherte Prozedur
CREATE PROCEDURE dbo.pSetLinkedServer
AS
SET NOCOUNT ON;
EXECUTE sp_addlinkedserver @server = N'SQLEXTERN', @srvproduct = N'SQL Server';
EXECUTE sp_addlinkedsrvlogin @rmtsrvname = N'SQLEXTERN', @useself = N'false', @locallogin = N'WSSQL2017\Jungbluth', @rmtuser = N'RemoteKonto', @rmtpassword = N'SNEK 2018 ist kein sicheres Kennwort!';
GO

-- Daten
SET NOCOUNT ON;

SET IDENTITY_INSERT dbo.Regionen ON 
INSERT dbo.Regionen (RegionID, Region) VALUES (1, N'Baden-Wrttemberg')
INSERT dbo.Regionen (RegionID, Region) VALUES (2, N'Bayern')
INSERT dbo.Regionen (RegionID, Region) VALUES (3, N'Berlin')
INSERT dbo.Regionen (RegionID, Region) VALUES (4, N'Cunewald')
INSERT dbo.Regionen (RegionID, Region) VALUES (5, N'Hessen')
INSERT dbo.Regionen (RegionID, Region) VALUES (6, N'Niedersachsen')
INSERT dbo.Regionen (RegionID, Region) VALUES (7, N'Nordrhein-Westfalen')
INSERT dbo.Regionen (RegionID, Region) VALUES (8, N'Rheinland-Pfalz')
INSERT dbo.Regionen (RegionID, Region) VALUES (9, N'Sachsen')
SET IDENTITY_INSERT dbo.Regionen OFF
GO

SET IDENTITY_INSERT dbo.Kontakte ON 
INSERT dbo.Kontakte (KontaktID, Kontaktart, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (1, N'K', N'Alfreds Sockenladen', N'Inh. Alfred Kiste', N'Mauerweg 8', N'Berlin', 3, N'12209', N'Deutschland', N'030-0074321', N'info@alfreds-sockenladen.de')
INSERT dbo.Kontakte (KontaktID, Kontaktart, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (2, N'K', N'Zur farbigen Socke', N'Socken in allen Farben, Formen und Gren', N'Retterstr. 10', N'Mannheim', 1, N'68306', N'Deutschland', N'0621-08460', N'zur.blauen.socke@blauesocke.de')
INSERT dbo.Kontakte (KontaktID, Kontaktart, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (3, N'K', N'Socks', N'Come in and find Socks', N'Gartenstr. 17', N'Mnchen', 2, N'80805', N'Deutschland', N'089-039123', N'socks@socks.de')
INSERT dbo.Kontakte (KontaktID, Kontaktart, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (4, N'K', N'Franks Sockenladen', N'Der Second-Foot Shop', N'Ideenplatz 9', N'Aachen', 7, N'52066', N'Deutschland', NULL, N'frank.sockenladen@franksockenladen.de')
INSERT dbo.Kontakte (KontaktID, Kontaktart, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (5, N'K', N'Socks To Run', N'Socken fr den Lufer', N'Pianoweg 11', N'Aschaffenburg', 5, N'63701', N'Deutschland', N'9876', N'socks.to.go@socktogo.com')
INSERT dbo.Kontakte (KontaktID, Kontaktart, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (6, N'K', N'Lehmanns Socken', N'Socken fr Manager', N'Hessengasse 435', N'Frankfurt', 5, N'60528', N'Deutschland', N'069-0245984', N'lehmanns.socken@lehmann.de')
INSERT dbo.Kontakte (KontaktID, Kontaktart, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (7, N'K', N'Morgenstern Socken', N'Socken fr Tag und Nacht', N'Kopperweg 11', N'Leipzig', 9, N'04179', N'Deutschland', N'3176', N'morgenstern.socken@morgenstern.de')
INSERT dbo.Kontakte (KontaktID, Kontaktart, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (8, N'K', N'Olivia Modeladen', N'Inh. Frau Pop-Eye', N'Severinstr. 77', N'Kln', 7, N'50739', N'Deutschland', N'0221-0644327', N'ottilies.modeladen@hotmail.de')
INSERT dbo.Kontakte (KontaktID, Kontaktart, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (9, N'K', N'Socken-Stop', NULL, N'Waldweg 11', N'Cunewalde', 4, N'01307', N'Deutschland', N'0372-035188', N'socken.shop@sockenstop.com')
INSERT dbo.Kontakte (KontaktID, Kontaktart, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (10, N'K', N'Toms Socken', NULL, N'Billstrae 88', N'Mnster', 7, N'44087', N'Deutschland', N'0251-031259', N'toms.socken@online.com')
INSERT dbo.Kontakte (KontaktID, Kontaktart, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (11, N'K', N'Wanderparadies', N'Outdoorkleidung und Zubehr', N'ttinger Pfad 8', N'Stuttgart', 1, N'70563', N'Deutschland', N'0711-020361', N'wanderparadies@web.de')
INSERT dbo.Kontakte (KontaktID, Kontaktart, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (12, N'L', N'Textilien Schmitthuber GmbH', NULL, N'Trabantgasse 78', N'Berlin', 3, N'10785', N'Deutschland', N'9984510', N'info@schmitthuber.de')
INSERT dbo.Kontakte (KontaktID, Kontaktart, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (13, N'L', N'Sportwaren Kunze AG', NULL, N'Rodgauer Strae 9', N'Frankfurt', 5, N'60439', N'Deutschland', N'992755', N'info@sportwaren-kunze.de')
INSERT dbo.Kontakte (KontaktID, Kontaktart, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (14, N'L', N'Karl Meier GmbH ', NULL, N'Am Kai 8', N'Cuxhaven', 6, N'27478', N'Deutschland', N'8713', N'info@karlmeier.com')
INSERT dbo.Kontakte (KontaktID, Kontaktart, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (15, N'K', N'Modeland Meier', N'Qualittsware fr die Dame und den Herren', N'Kirchhof 8', N'Neunkirchen', 2, N'63930', N'Deutschland', N'9967', N'post@gmx.de')
INSERT dbo.Kontakte (KontaktID, Kontaktart, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (16, N'K', N'Socks & More', N'Come in and find more', N'Gartenstr. 117', N'Simmern', 8, N'55469', N'Deutschland', N'06761 98547112', N'email@socksandmore.de')
INSERT dbo.Kontakte (KontaktID, Kontaktart, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (17, N'K', N'Flos Sockenladen', N'Socken fr das Haustier', N'Wiesenweg 9', N'Mnchen ', 2, N'80808', N'Deutschland', N'978765', N'flos.sockenladen@toffline.com')
SET IDENTITY_INSERT dbo.Kontakte OFF
GO

SET IDENTITY_INSERT dbo.Ansprechpartner ON 
INSERT dbo.Ansprechpartner (AnsprechpartnerID, KontaktID, Nachname, Vorname, Anrede, Position, Telefon, Mobil, Email) VALUES (1, 1, N'Neumann', N'Alfred', N'Herr', N'Inhaber', N'(030) 89 88 00', N'0163/9999999', N'mad@alfreds-sockenladen.de')
INSERT dbo.Ansprechpartner (AnsprechpartnerID, KontaktID, Nachname, Vorname, Anrede, Position, Telefon, Mobil, Email) VALUES (2, 1, N'Becker', N'Hilde', N'Frau', N'Geschftsfhrer', N'08798-9993', NULL, N'becker@alfreds-sockenladen.de')
INSERT dbo.Ansprechpartner (AnsprechpartnerID, KontaktID, Nachname, Vorname, Anrede, Position, Telefon, Mobil, Email) VALUES (3, 2, N'Becker', N'Heinz', N'Herr', N'Lehrling', N'0621-08460-12', NULL, N'becker@blauesocke.de')
INSERT dbo.Ansprechpartner (AnsprechpartnerID, KontaktID, Nachname, Vorname, Anrede, Position, Telefon, Mobil, Email) VALUES (4, 4, N'Schmitt', N'Rainer', N'Herr', N'Sachbearbeiter', NULL, NULL, N'rainer.schmitt@franksockenladen.de')
INSERT dbo.Ansprechpartner (AnsprechpartnerID, KontaktID, Nachname, Vorname, Anrede, Position, Telefon, Mobil, Email) VALUES (5, 3, N'Meier', N'Michael', N'Herr', N'Vertriebsmitarbeiter', N'089-039123', NULL, N'michael@socks.de')
INSERT dbo.Ansprechpartner (AnsprechpartnerID, KontaktID, Nachname, Vorname, Anrede, Position, Telefon, Mobil, Email) VALUES (6, 2, N'Beckerlein', N'Jens', N'Herr', N'Vertriebsmitarbeiter', N'0621-08460-15', NULL, NULL)
INSERT dbo.Ansprechpartner (AnsprechpartnerID, KontaktID, Nachname, Vorname, Anrede, Position, Telefon, Mobil, Email) VALUES (7, 3, N'Mller', N'Herbert', N'Herr', N'Vertriebsmitarbeiter', N'089-039123', NULL, N'herbert@socks.de')
INSERT dbo.Ansprechpartner (AnsprechpartnerID, KontaktID, Nachname, Vorname, Anrede, Position, Telefon, Mobil, Email) VALUES (8, 5, N'Ottoman', N'Frank', N'Herr', N'Inhaber', NULL, NULL, N'ottoman@socktogo.com')
INSERT dbo.Ansprechpartner (AnsprechpartnerID, KontaktID, Nachname, Vorname, Anrede, Position, Telefon, Mobil, Email) VALUES (9, 6, N'Meier', N'Jens', N'Herr', N'Sachbearbeiter', N'069-0245984', NULL, N'jens.meier@lehmann.de')
INSERT dbo.Ansprechpartner (AnsprechpartnerID, KontaktID, Nachname, Vorname, Anrede, Position, Telefon, Mobil, Email) VALUES (10, 7, N'Morgenstern', N'Johanna', N'Frau', N'Inhaber', NULL, NULL, N'ms@morgenstern.de')
INSERT dbo.Ansprechpartner (AnsprechpartnerID, KontaktID, Nachname, Vorname, Anrede, Position, Telefon, Mobil, Email) VALUES (11, 8, N'Ottoman', N'Ottilie', N'Frau', N'Inhaber', N'0221-0644327', NULL, N'ottilie.ottoman@hotmail.de')
INSERT dbo.Ansprechpartner (AnsprechpartnerID, KontaktID, Nachname, Vorname, Anrede, Position, Telefon, Mobil, Email) VALUES (12, 9, N'Strumpf', N'Karl-Heinz', N'Herr', N'Geschftsfhrer', N'0372-035188', NULL, N'strumpf@sockenstop.com')
INSERT dbo.Ansprechpartner (AnsprechpartnerID, KontaktID, Nachname, Vorname, Anrede, Position, Telefon, Mobil, Email) VALUES (13, 10, N'Pfeffer', N'Tom', N'Herr', N'Inhaber', N'0251-031259', NULL, N'pfeffer@online.com')
INSERT dbo.Ansprechpartner (AnsprechpartnerID, KontaktID, Nachname, Vorname, Anrede, Position, Telefon, Mobil, Email) VALUES (14, 11, N'Grnling', N'Claudia', N'Frau', N'Sachbearbeiter', N'0711-020361-8', NULL, N'claudiag@web.de')
INSERT dbo.Ansprechpartner (AnsprechpartnerID, KontaktID, Nachname, Vorname, Anrede, Position, Telefon, Mobil, Email) VALUES (15, 12, N'Schmitthuber', N'Waltraud', N'Frau', N'Inhaber', NULL, NULL, N'schmitthuber@schmitthuber.de')
INSERT dbo.Ansprechpartner (AnsprechpartnerID, KontaktID, Nachname, Vorname, Anrede, Position, Telefon, Mobil, Email) VALUES (16, 13, N'Kunze', N'Wilhelm', N'Herr', N'Geschftsfhrer', NULL, NULL, N'kunze@sportwaren-kunze.de')
INSERT dbo.Ansprechpartner (AnsprechpartnerID, KontaktID, Nachname, Vorname, Anrede, Position, Telefon, Mobil, Email) VALUES (17, 14, N'Meier', N'Karl', N'Herr', N'Inhaber', NULL, NULL, N'meier@karlmeier.com')
INSERT dbo.Ansprechpartner (AnsprechpartnerID, KontaktID, Nachname, Vorname, Anrede, Position, Telefon, Mobil, Email) VALUES (18, 15, N'Federhuhn', N'Barbara', N'Frau', N'Sachbearbeiter', NULL, NULL, N'federhuhn@gmx.de')
INSERT dbo.Ansprechpartner (AnsprechpartnerID, KontaktID, Nachname, Vorname, Anrede, Position, Telefon, Mobil, Email) VALUES (19, 17, N'Hutmann', N'Florian', N'Herr', N'Sachbearbeiter', NULL, NULL, N'hutmann@toffline.com')
INSERT dbo.Ansprechpartner (AnsprechpartnerID, KontaktID, Nachname, Vorname, Anrede, Position, Telefon, Mobil, Email) VALUES (20, 16, N'Loeffelchen', N'Birgit', N'Frau', N'Inhaber', NULL, NULL, N'loeffel@socksandmore.com')
SET IDENTITY_INSERT dbo.Ansprechpartner OFF
GO

SET IDENTITY_INSERT Personal.Mitarbeiter ON 
INSERT Personal.Mitarbeiter (MitarbeiterID, PersonalNr, Nachname, Vorname, Position, Anrede, Geburtsdatum, Einstellung, Durchwahl, Mobil, Email, Bemerkungen, Vorgesetzter, AktuellesGehalt, Religion, BenutzerID) VALUES (1, N'SP1988020800', N'Schmitt', N'Petra', N'Vertrieb', N'Frau', CAST(N'1988-02-08T00:00:00.0000000' AS DateTime2), CAST(N'2011-06-01T00:00:00.0000000' AS DateTime2), N'145', NULL, N'petra.schmitt@coolesocke.com', N'', 8, 3000.0000, N'Keltisch', NULL)
INSERT Personal.Mitarbeiter (MitarbeiterID, PersonalNr, Nachname, Vorname, Position, Anrede, Geburtsdatum, Einstellung, Durchwahl, Mobil, Email, Bemerkungen, Vorgesetzter, AktuellesGehalt, Religion, BenutzerID) VALUES (2, N'FA1992081900', N'Hoppenstett', N'Andreas', N'Geschftsfhrer', N'Herr', CAST(N'1992-08-19T00:00:00.0000000' AS DateTime2), CAST(N'2000-02-01T00:00:00.0000000' AS DateTime2), N'100', NULL, N'andreas.fueller@coolesocke.com', N'', NULL, 7500.0000, N'Keltisch', 0x0105000000000005150000003A64BB3FB420A7C9B63697B104040000)
INSERT Personal.Mitarbeiter (MitarbeiterID, PersonalNr, Nachname, Vorname, Position, Anrede, Geburtsdatum, Einstellung, Durchwahl, Mobil, Email, Bemerkungen, Vorgesetzter, AktuellesGehalt, Religion, BenutzerID) VALUES (3, N'LJ1993093000', N'Lebering', N'Jutta', N'Vertrieb', N'Frau', CAST(N'1993-09-30T00:00:00.0000000' AS DateTime2), CAST(N'2010-12-01T00:00:00.0000000' AS DateTime2), N'146', NULL, N'jutta.lebering@coolesocke.com', N'', 8, 4000.0000, N'Keltisch', NULL)
INSERT Personal.Mitarbeiter (MitarbeiterID, PersonalNr, Nachname, Vorname, Position, Anrede, Geburtsdatum, Einstellung, Durchwahl, Mobil, Email, Bemerkungen, Vorgesetzter, AktuellesGehalt, Religion, BenutzerID) VALUES (4, N'PM1998011900', N'Pfau', N'Margarete', N'Vertrieb', N'Frau', CAST(N'1998-01-19T00:00:00.0000000' AS DateTime2), CAST(N'2007-01-01T00:00:00.0000000' AS DateTime2), N'147', NULL, N'margarete.pfau@coolesocke.com', N'', 8, 3333.0000, N'Keltisch', NULL)
INSERT Personal.Mitarbeiter (MitarbeiterID, PersonalNr, Nachname, Vorname, Position, Anrede, Geburtsdatum, Einstellung, Durchwahl, Mobil, Email, Bemerkungen, Vorgesetzter, AktuellesGehalt, Religion, BenutzerID) VALUES (5, N'BS1987040300', N'Buch', N'Stefan', N'Vertriebsleiter', N'Herr', CAST(N'1987-04-03T00:00:00.0000000' AS DateTime2), CAST(N'2001-05-01T00:00:00.0000000' AS DateTime2), N'141', NULL, N'stefan.buch@coolesocke.com', N'', 2, 5000.0000, N'Keltisch', NULL)
INSERT Personal.Mitarbeiter (MitarbeiterID, PersonalNr, Nachname, Vorname, Position, Anrede, Geburtsdatum, Einstellung, Durchwahl, Mobil, Email, Bemerkungen, Vorgesetzter, AktuellesGehalt, Religion, BenutzerID) VALUES (6, N'SM1986020700', N'Sumann', N'Michael', N'Einkaufsleiter', N'Herr', CAST(N'1986-02-07T00:00:00.0000000' AS DateTime2), CAST(N'2003-04-01T00:00:00.0000000' AS DateTime2), N'142', NULL, N'michael.sumann@coolesocke.com', N'', 8, 3100.0000, N'Keltisch', NULL)
INSERT Personal.Mitarbeiter (MitarbeiterID, PersonalNr, Nachname, Vorname, Position, Anrede, Geburtsdatum, Einstellung, Durchwahl, Mobil, Email, Bemerkungen, Vorgesetzter, AktuellesGehalt, Religion, BenutzerID) VALUES (7, N'KP1996092900', N'Knig', N'Patrick', N'Einkauf', N'Herr', CAST(N'1996-09-29T00:00:00.0000000' AS DateTime2), CAST(N'2001-01-02T00:00:00.0000000' AS DateTime2), N'143', NULL, N'patrick.koenig@coolesocke.com', N'', 8, 3300.0000, N'Keltisch', NULL)
INSERT Personal.Mitarbeiter (MitarbeiterID, PersonalNr, Nachname, Vorname, Position, Anrede, Geburtsdatum, Einstellung, Durchwahl, Mobil, Email, Bemerkungen, Vorgesetzter, AktuellesGehalt, Religion, BenutzerID) VALUES (8, N'KL1998090100', N'Kallaman', N'Laura', N'Einkauf', N'Frau', CAST(N'1998-09-01T00:00:00.0000000' AS DateTime2), CAST(N'2005-09-01T00:00:00.0000000' AS DateTime2), N'144', NULL, N'laura.kallaman@coolesocke.com', N'', 5, 3300.0000, N'Keltisch', 0x0105000000000005150000003A64BB3FB420A7C9B63697B105040000)
INSERT Personal.Mitarbeiter (MitarbeiterID, PersonalNr, Nachname, Vorname, Position, Anrede, Geburtsdatum, Einstellung, Durchwahl, Mobil, Email, Bemerkungen, Vorgesetzter, AktuellesGehalt, Religion, BenutzerID) VALUES (9, N'LA1995042200', N'Lebhausen', N'Anna', N'Einkauf', N'Frau', CAST(N'1995-04-22T00:00:00.0000000' AS DateTime2), CAST(N'2002-11-01T00:00:00.0000000' AS DateTime2), N'145', NULL, N'anna.lebhausen@coolesocke.com', N'', 8, 3000.0000, N'Keltisch', 0x0105000000000005150000003A64BB3FB420A7C9B63697B106040000)
SET IDENTITY_INSERT Personal.Mitarbeiter OFF
GO

SET IDENTITY_INSERT Personal.Bewerber ON 
INSERT Personal.Bewerber (BewerberID, StellenID, Nachname, Vorname, Strasse, Hausnummer, PLZ, Ort, Geburtsdatum, Mobil, Email, Gehaltswunsch, Religion, Bemerkungen) VALUES (1, N'118', N'Mller-Ldenscheid', N'Karl-Heinz', N'Bulwstr.', N'5', N'12345', N'Loriotsen', CAST(N'2011-11-11T00:00:00.0000000' AS DateTime2), NULL, N'kh@mueller-luedenscheid.de', 4000.0000, N'keltisch', NULL)
INSERT Personal.Bewerber (BewerberID, StellenID, Nachname, Vorname, Strasse, Hausnummer, PLZ, Ort, Geburtsdatum, Mobil, Email, Gehaltswunsch, Religion, Bemerkungen) VALUES (2, N'118', N'Hoppenstett', N'Maria', N'lbuwstr.', N'5', N'23456', N'Dahinten', CAST(N'2018-01-10T00:00:00.0000000' AS DateTime2), NULL, N'maria@hoppenstett.de', 4000.0000, N'keltisch', NULL)
SET IDENTITY_INSERT Personal.Bewerber OFF
GO

SET IDENTITY_INSERT Verkauf.Gebietszuordnungen ON 
INSERT Verkauf.Gebietszuordnungen (GebietszuordnungID, MitarbeiterID, RegionID) VALUES (1, 2, 9)
INSERT Verkauf.Gebietszuordnungen (GebietszuordnungID, MitarbeiterID, RegionID) VALUES (2, 3, 2)
INSERT Verkauf.Gebietszuordnungen (GebietszuordnungID, MitarbeiterID, RegionID) VALUES (3, 9, 7)
INSERT Verkauf.Gebietszuordnungen (GebietszuordnungID, MitarbeiterID, RegionID) VALUES (4, 6, 1)
INSERT Verkauf.Gebietszuordnungen (GebietszuordnungID, MitarbeiterID, RegionID) VALUES (5, 6, 2)
INSERT Verkauf.Gebietszuordnungen (GebietszuordnungID, MitarbeiterID, RegionID) VALUES (6, 6, 3)
INSERT Verkauf.Gebietszuordnungen (GebietszuordnungID, MitarbeiterID, RegionID) VALUES (7, 8, 3)
INSERT Verkauf.Gebietszuordnungen (GebietszuordnungID, MitarbeiterID, RegionID) VALUES (8, 9, 8)
INSERT Verkauf.Gebietszuordnungen (GebietszuordnungID, MitarbeiterID, RegionID) VALUES (9, 7, 1)
INSERT Verkauf.Gebietszuordnungen (GebietszuordnungID, MitarbeiterID, RegionID) VALUES (10, 9, 5)
INSERT Verkauf.Gebietszuordnungen (GebietszuordnungID, MitarbeiterID, RegionID) VALUES (11, 9, 4)
INSERT Verkauf.Gebietszuordnungen (GebietszuordnungID, MitarbeiterID, RegionID) VALUES (12, 9, 6)
SET IDENTITY_INSERT Verkauf.Gebietszuordnungen OFF
GO
SET NOCOUNT OFF;

-- User und Rechte --> Bitte die LOGINs an eigene Anmeldungen anpassen
CREATE USER Kallaman FOR LOGIN [AnmeldungVonKallaman] WITH DEFAULT_SCHEMA=dbo;
CREATE USER Lebhausen FOR LOGIN [AnmeldungVonLebhausen] WITH DEFAULT_SCHEMA=dbo;
CREATE USER Hoppenstett FOR LOGIN [AnmeldungVonHoppenstett] WITH DEFAULT_SCHEMA=dbo;
GO

-- SIDs fr Mitarbeiter --> Bitte die LOGINs an eigene Anmeldungen anpassen
DECLARE @SID VARBINARY(85);
SET @SID = (SELECT SID FROM syslogins WHERE loginname = 'AnmeldungVonKallaman');
UPDATE Personal.Mitarbeiter SET BenutzerID = @SID WHERE Nachname = 'Lebhausen';
SET @SID = (SELECT SID FROM syslogins WHERE loginname = 'AnmeldungVonKallaman');
UPDATE Personal.Mitarbeiter SET BenutzerID = @SID WHERE Nachname = 'Kallaman';
SET @SID = (SELECT SID FROM syslogins WHERE loginname = 'AnmeldungVonHoppenstett');
UPDATE Personal.Mitarbeiter SET BenutzerID = @SID WHERE Nachname = 'Hoppenstett';
GO