------------------------------------------------------
-- Beispielskript zur SNEK 6 im April 2018 in Nrnberg
-- Autor: Bernd Jungbluth
-- Keine Gewhrleistung, keine Haftung

-- Installation Beispieldatenbank SNEK 6
------------------------------------------------------

USE SNEK;
GO


-- Alle Ansprechpartner ausgeben
SELECT	DISTINCT 
		A.Nachname, A.Vorname, A.Telefon, A.Mobil, A.Email, A.Position, A.Anrede
FROM	Verkauf.Gebietszuordnungen G
		INNER JOIN	dbo.Kontakte K
					ON G.RegionID = K.RegionID
		INNER JOIN	dbo.Ansprechpartner A
						ON K.KontaktID = A.KontaktID
GO

-- Empfehlung: Eigenes Schema fr RLS anlegen
CREATE SCHEMA rls AUTHORIZATION dbo;
GO

-- Tabellenwertfunktion mit Regeldefinition erstellen
DROP FUNCTION IF EXISTS rls.rfBenutzerkonto;
GO
CREATE OR ALTER FUNCTION rls.rfBenutzerkonto(@MitarbeiterID int)
RETURNS TABLE 
WITH SCHEMABINDING AS
RETURN
	SELECT	
			1 As OK
	FROM
			Personal.Mitarbeiter 
	WHERE
			(@MitarbeiterID = MitarbeiterID 
			 AND
			 BenutzerID = SUSER_SID())
			 -- Nur zu Demozwecken: DBO darf die Daten auch sehen
			 OR DATABASE_PRINCIPAL_ID() = 1
GO

-- Security Policy erstellen
DROP SECURITY POLICY IF EXISTS rls.rsGebiete;
GO
CREATE SECURITY POLICY rls.rsGebiete
ADD 
	FILTER PREDICATE rls.rfBenutzerkonto(MitarbeiterID) 
		   ON Verkauf.Gebietszuordnungen
GO


-- Alle Ansprechpartner als DBO anzeigen
SELECT	DISTINCT 
		A.Nachname, A.Vorname, A.Telefon, A.Mobil, A.Email, A.Position, A.Anrede
FROM	Verkauf.Gebietszuordnungen G
		INNER JOIN	dbo.Kontakte K
					ON G.RegionID = K.RegionID
		INNER JOIN	dbo.Ansprechpartner A
						ON K.KontaktID = A.KontaktID
ORDER BY A.Nachname;


-- Identitt zu Kallaman wechseln und Ansprechpartner anzeigen
EXECUTE As USER = 'Kallaman';
SELECT	DISTINCT 
		A.Nachname, A.Vorname, A.Telefon, A.Mobil, A.Email, A.Position, A.Anrede
FROM	Verkauf.Gebietszuordnungen G
		INNER JOIN	dbo.Kontakte K
					ON G.RegionID = K.RegionID
		INNER JOIN	dbo.Ansprechpartner A
						ON K.KontaktID = A.KontaktID
ORDER BY A.Nachname;
REVERT;


-- Identitt zu Lebhausen wechseln und Ansprechpartner anzeigen
EXECUTE As USER = 'Lebhausen';
SELECT	DISTINCT 
		A.Nachname, A.Vorname, A.Telefon, A.Mobil, A.Email, A.Position, A.Anrede
FROM	Verkauf.Gebietszuordnungen G
		INNER JOIN	dbo.Kontakte K
					ON G.RegionID = K.RegionID
		INNER JOIN	dbo.Ansprechpartner A
						ON K.KontaktID = A.KontaktID
ORDER BY A.Nachname;
REVERT;


-- Gebietszuordnungen der Mitarbeiter Lebhausen und Kallaman ausgeben
SELECT	G.GebietszuordnungID, M.MitarbeiterID, Nachname, RegionID 
FROM	Verkauf.Gebietszuordnungen G 
		INNER JOIN	Personal.Mitarbeiter M 
					ON M.MitarbeiterID = G.MitarbeiterID
WHERE	M.MitarbeiterID IN (8, 9);


-- Als Mitarbeiter Lebhausen Gebiet 4 Mitarbeiter Kallaman zuordnen
EXECUTE As USER = 'Lebhausen';
UPDATE	Verkauf.Gebietszuordnungen
SET		MitarbeiterID = 8
WHERE	RegionID = 4;
REVERT;


-- Gebietszuordnungen der Mitarbeiter Lebhausen und Kallaman ausgeben
SELECT	G.GebietszuordnungID, M.MitarbeiterID, Nachname, RegionID 
FROM	Verkauf.Gebietszuordnungen G 
		INNER JOIN	Personal.Mitarbeiter M 
					ON M.MitarbeiterID = G.MitarbeiterID
WHERE	M.MitarbeiterID IN (8, 9);


-- Security Policy um Block Predicate erweitern
ALTER SECURITY POLICY rls.rsGebiete
ADD
	BLOCK PREDICATE rls.rfBenutzerkonto(MitarbeiterID) 
		  ON Verkauf.Gebietszuordnungen AFTER UPDATE;
GO


-- Als Mitarbeiter Lebhausen Gebiet 4 Mitarbeiter Kallaman zuordnen
EXECUTE As USER = 'Lebhausen';
UPDATE	Verkauf.Gebietszuordnungen
SET		MitarbeiterID = 8
WHERE	RegionID = 5;
REVERT;
--> Fehler - ausgelst duch Block Predicate AFTER INSERT