------------------------------------------------------
-- Beispielskript zur SNEK 6 im April 2018 in Nrnberg
-- Autor: Bernd Jungbluth
-- Keine Gewhrleistung, keine Haftung

-- Installation Beispieldatenbank SNEK 6
------------------------------------------------------

USE master;
GO


-- SQL Server Audit anlegen
CREATE SERVER AUDIT [Datenschutz] TO FILE 
(	
	FILEPATH = N'D:\DSGVO und SQL Server\Audit'
	,MAXSIZE = 0 MB
	,MAX_ROLLOVER_FILES = 2147483647
	,RESERVE_DISK_SPACE = OFF
)
WITH (QUEUE_DELAY = 1000, ON_FAILURE = CONTINUE)
GO
-- SQL Server Audit starten
ALTER SERVER AUDIT [Datenschutz] WITH (STATE = ON)
GO

-- Server Level Auditing anlegen
CREATE SERVER AUDIT SPECIFICATION [Zugriffsrechte]
FOR SERVER AUDIT [Datenschutz]
ADD (BACKUP_RESTORE_GROUP),
ADD (FAILED_LOGIN_GROUP),
ADD (FAILED_DATABASE_AUTHENTICATION_GROUP),
ADD (SERVER_ROLE_MEMBER_CHANGE_GROUP),
ADD (SERVER_OBJECT_PERMISSION_CHANGE_GROUP),
ADD (DATABASE_ROLE_MEMBER_CHANGE_GROUP),
ADD (DATABASE_OBJECT_PERMISSION_CHANGE_GROUP)
WITH (STATE = ON)
GO


USE SNEK;
GO

-- Database Level Auditing anlegen
CREATE DATABASE AUDIT SPECIFICATION [Personenbezogene Daten]
FOR SERVER AUDIT Datenschutz
	ADD (SELECT ON OBJECT::Personal.Mitarbeiter BY Kallaman, Lebhausen, Hoppenstett),
	ADD (SELECT ON OBJECT::Personal.Bewerber BY Kallaman, Lebhausen, Hoppenstett),
	ADD (SELECT ON OBJECT::dbo.Ansprechpartner BY Kallaman, Lebhausen, Hoppenstett)
WITH (STATE = ON)
GO

-- Daten lesen als Kallaman
EXECUTE As USER = 'Kallaman';
SELECT	Nachname, Vorname, Telefon, Mobil, Email, Position, Anrede
FROM	dbo.Ansprechpartner;
REVERT;
-- Daten lesen als Hoppenstett
EXECUTE As USER = 'Hoppenstett';
SELECT	Nachname, Vorname, Telefon, Mobil, Email, Position, Anrede
FROM	dbo.Ansprechpartner;
REVERT;
-- Daten lesen als Lebhausen
EXECUTE As USER = 'Lebhausen';
SELECT	Nachname, Vorname, Telefon, Mobil, Email, Position, Anrede
FROM	dbo.Ansprechpartner;
REVERT;


-- SQL Server Audit auswerten
SELECT 
		event_time As Zeitpunkt, server_principal_name As Benutzer,
		[database_name] As Datenbank, 
		CASE WHEN action_id = 'SL' THEN 'SELECT' END As Aktion,
		CONCAT([schema_name] + '.', [object_name]) As Objekt,
		[statement] As SqlAnweisung
FROM 
		sys.fn_get_audit_file('D:\DSGVO und SQL Server\Audit\*.sqlaudit', DEFAULT, DEFAULT)
WHERE 
		action_id = 'SL';

